Learn R Programming

pharmr (version 2.2.0)

broadcast_log: broadcast_log

Description

Broadcast the log of a context

Default is to use the same broadcaster, but optionally another broadcaster could be used.

Usage

broadcast_log(context, broadcaster = NULL)

Arguments

context

(Context) Broadcast the log of this context

broadcaster

(str (optional)) Name of the broadcaster to use. Default is to use the same as was original used.