get_cmt: get_cmt

View source: R/functions_wrapper.R

get_cmtR Documentation

get_cmt

Description

Get the cmt (compartment) column from the model dataset

If a cmt column is present this will be extracted otherwise a cmt column will be created. If created, multiple dose compartments are dependent on the presence of an admid type column, otherwise, dose/non-dose will be considered.

Usage

get_cmt(model)

Arguments

model

(Model) Pharmpy model

Value

(data.frame) CMT


pharmr documentation built on May 28, 2026, 5:08 p.m.