get_covariate_effects: get_covariate_effects

View source: R/functions_wrapper.R

get_covariate_effectsR Documentation

get_covariate_effects

Description

Return a list of all used covariates within a model

The list will have parameter name as key with a connected value as a vector of tuple(s) with (covariate, effect type, operator)

Usage

get_covariate_effects(model)

Arguments

model

(Model) Pharmpy model

Value

(Dictionary : Dictionary of parameters and connected covariate(s))


pharmr documentation built on May 28, 2026, 5:08 p.m.