powered by
Return nested model from a pair of models
Function to get a nested model from a pair of models, NULL if neither model is nested. A model is not considered nested if:
They are the same model
They have the same number of parameters
The parameters of the reduced model is not a subset of the extended model
The dosing or DV is changed
Assumptions made:
Parametrization is the same
Parameter names are the same
get_nested_model(model_1, model_2)
(Model | NULL) Pharmpy model or NULL
(Model) Pharmpy model
if (FALSE) { model_1 <- load_example_model("pheno") model_2 <- add_peripheral_compartment(model_1) model_2 <- set_name(model_2, 'pheno_2') nested <- get_nested_model(model_1, model_2) nested$name }
Run the code above in your browser using DataLab