has_first_order_absorption: has_first_order_absorption
Description
Check if ode system describes a first order absorption
Currently defined as the central compartment having a unidirectional input
flow from another compartment (such as depot or transit)
Usage
has_first_order_absorption(model)
Value
(logical) TRUE if model has first order absorption
Arguments
- model
(Model) Pharmpy model