infer_datatypes: infer_datatypes

View source: R/functions_wrapper.R

infer_datatypesR Documentation

infer_datatypes

Description

Infer and set datatypes for the dataset

All columns or only the ones set in the columns option will be checked for conversion to a simpler datatype. Currently only int32 will be checked since this corresponds to the integer type in R.

Usage

infer_datatypes(model, columns = NULL)

Arguments

model

(Model) Pharmpy model

columns

(array(str) (optional)) The columns to attempt conversion or NULL for all

Value

(Model) Updated Pharmpy model

Examples

## Not run: 
model <- load_example_model("pheno")
model <- infer_datatypes(model, c('APGR'))
model$dataset

## End(Not run)


pharmr documentation built on May 28, 2026, 5:08 p.m.