View source: R/functions_wrapper.R
| is_binary | R Documentation |
Check if an expression defines a binary variable (only having values 0 and 1)
is_binary(model, expr)
model |
(Model) Pharmpy model |
expr |
(str) A mathematical expression containing column or variable names |
(logical) TRUE if binary
## Not run:
model <- load_example_model("pheno")
is_binary(model, "WGT")
is_binary(model, "FA1")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.