Learn R Programming

pharmr (version 2.2.0)

list_models: list_models

Description

List names of all models in a context

Will by default vector only models in the top level, but can vector all recursively using the recursive option. This will add the context path to each model name as a qualifier.

Usage

list_models(context, recursive = FALSE)

Value

(vectorc(str)) A vector of the model names

Arguments

context

(Context) The context

recursive

(logical) Only top level or all levels recursively down.