print_model_symbols: print_model_symbols

View source: R/functions_wrapper.R

print_model_symbolsR Documentation

Description

Print all symbols defined in a model

Symbols will be in one of the categories thetas, etas, omegas, epsilons, sigmas, variables and data columns

Usage

print_model_symbols(model)

Arguments

model

(Model) Pharmpy model

Examples

## Not run: 
model <- load_example_model("pheno")
print_model_symbols(model)

## End(Not run)


pharmr documentation built on May 28, 2026, 5:08 p.m.