replace_non_random_rvs: replace_non_random_rvs

View source: R/functions_wrapper.R

replace_non_random_rvsR Documentation

replace_non_random_rvs

Description

Replace all random variables that are not actually random

Some random variables are constant. For example a normal distribution with the variance parameter fixed to 0 will always yield a single value when sampled. This function will find all such random variables and replace them with their constant value in the model.

Usage

replace_non_random_rvs(model)

Arguments

model

(Model) Pharmpy model

Value

(Model) Updated Pharmpy model


pharmr documentation built on May 28, 2026, 5:08 p.m.