Learn R Programming

pharmr (version 2.2.0)

retrieve_model: retrieve_model

Description

Retrieve a model from a context

Any models created and run by the tool can be retrieved.

Usage

retrieve_model(context, name)

Value

(Model) Pharmpy model

Arguments

context

(Context) A previously opened context

name

(str) Name of the model or a qualified name with a subcontext path, e.g.

Examples

Run this code
if (FALSE) {
context <- open_context(ref='path/to/', name='modelsearch1')
model <- retrieve_model(context, 'run1')
}

Run the code above in your browser using DataLab