View source: R/functions_wrapper.R
| run_bootstrap | R Documentation |
Run bootstrap tool
run_bootstrap(
model,
results = NULL,
samples = 1,
dofv = FALSE,
strictness = "",
...
)
model |
(Model) Pharmpy model |
results |
(ModelfitResults (optional)) Results for model |
samples |
(numeric) Number of bootstrap resamples |
dofv |
(logical) Will evaluate bootstrap models with original dataset if set |
strictness |
(str) Strictness expression for which models should be used in the calculations. Default is all models |
... |
Arguments to pass to tool |
(BootstrapResults) Bootstrap tool result object
## Not run:
model <- load_example_model("pheno")
results <- load_example_modelfit_results("pheno")
run_bootstrap(model, res, samples=500)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.