(str) Which algorithm to run when determining number of IIVs.
search_space
(str) Search space to explore
as_fullblock
(logical) Whether to add IIVs as a fullblock
rank_type
(str) Which ranking type should be used. Default is BIC.
linearize
(logical) Wheter or not use linearization when running the tool.
cutoff
(numeric (optional)) Cutoff for which value of the ranking function that is considered significant. Default
is NULL (all models will be ranked)
strictness
(str) Strictness criteria
correlation_algorithm
(str (optional)) Which algorithm to run for the determining block structure of added IIVs. If NULL, the
algorithm is determined based on the 'algorithm' argument
E_p
(numeric or str (optional)) Expected number of predictors for diagonal elements (used for mBIC). Must be set when using mBIC and
when the argument 'algorithm' is not 'skip'
E_q
(numeric or str (optional)) Expected number of predictors for off-diagonal elements (used for mBIC). Must be set when using mBIC
and when the argument correlation_algorithm is not skip or NULL
parameter_uncertainty_method
(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes
parameter uncertaint