run_modelrank: run_modelrank

View source: R/functions_wrapper.R

run_modelrankR Documentation

run_modelrank

Description

Run ModelRank tool.

Usage

run_modelrank(
  models,
  results,
  ref_model,
  strictness = "minimization_successful or (rounding_errors and sigdigs >= 0.1)",
  rank_type = "ofv",
  alpha = 0.05,
  search_space = NULL,
  E = NULL,
  parameter_uncertainty_method = NULL,
  exclude_reference_model = FALSE,
  ...
)

Arguments

models

(array(Model)) Models to rank

results

(array(ModelfitResults)) Modelfit results to rank on

ref_model

(Model) Model to compare to

strictness

(str) Strictness criteria

rank_type

(str) Which ranking type should be used. Supported types are OFV, LRT, AIC, BIC (mixed, IIV, random), and mBIC (mixed, IIV, random). Default is OFV.

alpha

(numeric (optional)) Cutoff p-value that is considered significant in likelihood ratio test. Default is NULL

search_space

(str or ModelFeatures (optional)) Search space to test. Either as a string or a ModelFeatures object.

E

(numeric or str or list(numeric or str,numeric or str) (optional)) Expected number of predictors (used for mBIC). Must be set when using mBIC. Tuple if mBIC for IIV (both diagonals and off-diagonals)

parameter_uncertainty_method

(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes parameter uncertainty

exclude_reference_model

(logical) Should it be possible to select the reference model? Default is TRUE

...

Arguments to pass to tool

Value

(ModelRankResults) ModelRank tool result object


pharmr documentation built on May 28, 2026, 5:08 p.m.