run_structsearch: run_structsearch

View source: R/functions_wrapper.R

run_structsearchR Documentation

run_structsearch

Description

Run the structsearch tool. For more details, see :ref:structsearch.

Usage

run_structsearch(
  model,
  results,
  type,
  search_space = NULL,
  b_init = NULL,
  emax_init = NULL,
  ec50_init = NULL,
  met_init = NULL,
  extra_model = NULL,
  rank_type = "bic",
  cutoff = NULL,
  strictness = "minimization_successful or (rounding_errors and sigdigs >= 0.1)",
  extra_model_results = NULL,
  dv_types = NULL,
  parameter_uncertainty_method = NULL,
  ...
)

Arguments

model

(Model) Pharmpy start model

results

(ModelfitResults) Results for the start model

type

(str) Type of model. Currently only 'drug_metabolite', 'pkpd' and 'tmdd'

search_space

(str or ModelFeatures (optional)) Search space to test

b_init

(numeric (optional)) Initial estimate for the baseline for pkpd models.

emax_init

(numeric (optional)) Initial estimate for E_MAX (for pkpd models only).

ec50_init

(numeric (optional)) Initial estimate for EC_50 (for pkpd models only).

met_init

(numeric (optional)) Initial estimate for MET (for pkpd models only).

extra_model

(Model (optional)) Optional extra Pharmpy model to use in TMDD structsearch

rank_type

(str) Results for the extra model

cutoff

(numeric (optional)) Which ranking type should be used. Default is BIC.

strictness

(str (optional)) Cutoff for which value of the ranking function that is considered significant. Default is NULL (all models will be ranked)

extra_model_results

(ModelfitResults (optional)) Strictness criteria

dv_types

(list(str=numeric) (optional)) Dictionary of DV types for TMDD models with multiple DVs

parameter_uncertainty_method

(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes parameter uncertaint

...

Arguments to pass to tool

Value

(StructSearchResult) structsearch tool result object

Examples

## Not run: 
model <- load_example_model("pheno")
results <- load_example_modelfit_results("pheno")
run_structsearch(model=model, results=results, model_type='pkpd')

## End(Not run)


pharmr documentation built on May 28, 2026, 5:08 p.m.