Learn R Programming

pharmr (version 2.2.0)

set_direct_effect: set_direct_effect

Description

Add an effect to a model.

Effects are by default using concentratrion, but any user specified variable in the model can be used. Implemented PD models are:

  • Linear:

(equation could not be rendered, see API doc on website)

  • Emax:

(equation could not be rendered, see API doc on website)

  • Step effect:

(equation could not be rendered, see API doc on website)

  • Sigmoidal:

(equation could not be rendered, see API doc on website)

  • Log-linear:

(equation could not be rendered, see API doc on website)

(equation could not be rendered, see API doc on website)

Usage

set_direct_effect(model, expr, variable = NULL)

Value

(Model) Updated Pharmpy model

Arguments

model

(Model) Pharmpy model

expr

(str) Name of PD effect function.

variable

(str (optional)) Name of variable to use (if NULL concentration will be used)

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
model <- set_direct_effect(model, "linear")
model$statements$find_assignment("E")
}

Run the code above in your browser using DataLab