powered by
Set or change to first order absorption rate.
Initial estimate for absorption rate is set to the previous rate if available, otherwise it is set to the time of first observation/2.
If multiple doses is set to the affected compartment, currently only iv+oral doses (one of each) is supported
set_first_order_absorption(model)
(Model) Updated Pharmpy model
(Model) Pharmpy model
set_instantaneous_absorption
set_zero_order_absorption
if (FALSE) { model <- load_example_model("pheno") model <- set_first_order_absorption(model) model$statements$ode_system }
Run the code above in your browser using DataLab