View source: R/functions_wrapper.R
| set_transit_compartments | R Documentation |
Set the number of transit compartments of model.
Initial estimate for the absorption delay is set the previous delay if available, otherwise it is set to the time of first observation/2.
set_transit_compartments(model, n, keep_depot = TRUE)
model |
(Model) Pharmpy model |
n |
(numeric) Number of transit compartments |
keep_depot |
(logical) FALSE to convert depot compartment into a transit compartment |
(Model) Updated Pharmpy model
add_lag_time
set_n_transit_compartments
## Not run:
model <- load_example_model("pheno")
model <- set_transit_compartments(model, 3)
model$statements$ode_system
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.