Learn R Programming

pharmr (version 2.2.0)

translate_nmtran_time: translate_nmtran_time

Description

Translate NM-TRAN TIME and DATE column into one TIME column

If dataset of model have special NM-TRAN TIME and DATE columns these will be translated into one single time column with time in hours.

Warnings Use this function with caution. For example reset events are currently not taken into account.

Usage

translate_nmtran_time(model)

Value

(Model) Updated Pharmpy model

Arguments

model

(Model) Pharmpy model