write_model: write_model

View source: R/functions_wrapper.R

write_modelR Documentation

write_model

Description

Write model code to file

An updated Pharmpy model is returned. This will have a new name based on the filename and it might have updates to the model code (e.g. for $DATA in NONMEM models).

Usage

write_model(model, path = "", force = TRUE)

Arguments

model

(Model) Pharmpy model

path

(str) Destination path

force

(logical) Force overwrite, default is TRUE

Value

(Model) Updated Pharmpy model

Examples

## Not run: 
model <- load_example_model("pheno")
write_model(model)

## End(Not run)


pharmr documentation built on May 28, 2026, 5:08 p.m.