Derive the physical unit of a variable in the model
Unit information for the dataset needs to be available.
The variable can be defined in the code, a dataset column, a parameter
or a random variable. Optionally units could be derived for all variables
in the model.
Usage
get_unit_of(model, variable = NULL)
Value
(Unit) A unit expression
Arguments
model
(Model) Pharmpy model
variable
(str or Expr (optional)) Find physical unit of this variable. For NULL get a list with units for
all variables defined by the model.