View source: R/functions_wrapper.R
| infer_datatypes | R Documentation |
Infer and set datatypes for the dataset
All columns or only the ones set in the columns option will be checked for conversion to a simpler datatype. Currently only int32 will be checked since this corresponds to the integer type in R.
infer_datatypes(model, columns = NULL)
model |
(Model) Pharmpy model |
columns |
(array(str) (optional)) The columns to attempt conversion or NULL for all |
(Model) Updated Pharmpy model
## Not run:
model <- load_example_model("pheno")
model <- infer_datatypes(model, c('APGR'))
model$dataset
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.