Learn R Programming

pharmr (version 2.2.0)

infer_datatypes: infer_datatypes

Description

Infer and set datatypes for the dataset

All columns or only the ones set in the columns option will be checked for conversion to a simpler datatype. Currently only int32 will be checked since this corresponds to the integer type in R.

Usage

infer_datatypes(model, columns = NULL)

Value

(Model) Updated Pharmpy model

Arguments

model

(Model) Pharmpy model

columns

(array(str) (optional)) The columns to attempt conversion or NULL for all

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
model <- infer_datatypes(model, c('APGR'))
model$dataset
}

Run the code above in your browser using DataLab