View source: R/functions_wrapper.R
| plot_individual_predictions | R Documentation |
Plot DV and predictions grouped on individuals
The predictions would normally be taken from the modelfit results, but any data frame of appropriate format can be used. It should have one column per type of prediction where the column name is the type (e.g. "PRED" or "IPRED"), one row for each record of the dataset in the model. A predictions table containing only some of the individuals is ok to use, but then care needs to be taken to get match the row index of the original dataset.
plot_individual_predictions(model, predictions, individuals = NULL)
model |
(Model) Pharmpy model |
predictions |
(data.frame) One column for each type of prediction |
individuals |
(array(numeric) (optional)) A vector of individuals to include. NULL for all individuals |
(alt.Chart) Plot
## Not run:
model <- load_example_model("pheno")
res <- load_example_modelfit_results("pheno")
plot_individual_predictions(model, res$predictions, individuals=c(1, 2, 3, 4, 5))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.