View source: R/functions_wrapper.R
| remove_unused_columns | R Documentation |
Remove all columns in the dataset that are not used by the model including dropped columns
Warnings Currently columns not needed to give a prediction, but used by other expressions in the model are kept. This will change in the future.
remove_unused_columns(model)
model |
(Model) Pharmpy model |
(Model) Updated Pharmpy model
drop_columns : Drop columns from the dataset
## Not run:
model <- load_example_model("pheno")
model <- remove_unused_columns(model)
vector(model$dataset$columns)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.