Learn R Programming

pharmr (version 2.2.0)

remove_unused_columns: remove_unused_columns

Description

Remove all columns in the dataset that are not used by the model including dropped columns

Warnings Currently columns not needed to give a prediction, but used by other expressions in the model are kept. This will change in the future.

Usage

remove_unused_columns(model)

Value

(Model) Updated Pharmpy model

Arguments

model

(Model) Pharmpy model

See Also

drop_columns : Drop columns from the dataset

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
model <- remove_unused_columns(model)
vector(model$dataset$columns)
}

Run the code above in your browser using DataLab