powered by
Remove all columns in the dataset that are not used by the model including dropped columns
Warnings Currently columns not needed to give a prediction, but used by other expressions in the model are kept. This will change in the future.
remove_unused_columns(model)
(Model) Updated Pharmpy model
(Model) Pharmpy model
drop_columns : Drop columns from the dataset
if (FALSE) { model <- load_example_model("pheno") model <- remove_unused_columns(model) vector(model$dataset$columns) }
Run the code above in your browser using DataLab