powered by
Use Pharmpy dataset instead of original file
The parsed dataset will be written down when doing e.g. estimation or writing files instead of the original dataset file
Removes path and provenance from DataInfo.
Note: Use this to get same behavior as Pharmpy<=2.1.1
reset_dataset(model)
(Model) Updated Pharmpy model
(Model) Pharmpy model
if (FALSE) { model <- load_example_model("pheno") model <- reset_dataset(model) }
Run the code above in your browser using DataLab