powered by
Retrieve a model from a context
Any models created and run by the tool can be retrieved.
retrieve_model(context, name)
(Model) Pharmpy model
(Context) A previously opened context
(str) Name of the model or a qualified name with a subcontext path, e.g.
if (FALSE) { context <- open_context(ref='path/to/', name='modelsearch1') model <- retrieve_model(context, 'run1') }
Run the code above in your browser using DataLab