Learn R Programming

pharmr (version 2.2.0)

run_bootstrap: run_bootstrap

Description

Run bootstrap tool

Usage

run_bootstrap(
  model,
  results = NULL,
  samples = 1,
  dofv = FALSE,
  strictness = "",
  ...
)

Value

(BootstrapResults) Bootstrap tool result object

Arguments

model

(Model) Pharmpy model

results

(ModelfitResults (optional)) Results for model

samples

(numeric) Number of bootstrap resamples

dofv

(logical) Will evaluate bootstrap models with original dataset if set

strictness

(str) Strictness expression for which models should be used in the calculations. Default is all models

...

Arguments to pass to tool

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
results <- load_example_modelfit_results("pheno")
run_bootstrap(model, res, samples=500)
}

Run the code above in your browser using DataLab