powered by
Run bootstrap tool
run_bootstrap( model, results = NULL, samples = 1, dofv = FALSE, strictness = "", ... )
(BootstrapResults) Bootstrap tool result object
(Model) Pharmpy model
(ModelfitResults (optional)) Results for model
(numeric) Number of bootstrap resamples
(logical) Will evaluate bootstrap models with original dataset if set
(str) Strictness expression for which models should be used in the calculations. Default is all models
Arguments to pass to tool
if (FALSE) { model <- load_example_model("pheno") results <- load_example_modelfit_results("pheno") run_bootstrap(model, res, samples=500) }
Run the code above in your browser using DataLab