Learn R Programming

pharmr (version 2.2.0)

run_iovsearch: run_iovsearch

Description

Run IOVsearch tool. For more details, see :ref:iovsearch.

Usage

run_iovsearch(
  model,
  results,
  column = "OCC",
  list_of_parameters = NULL,
  rank_type = "bic",
  cutoff = NULL,
  distribution = "same-as-iiv",
  strictness = "minimization_successful or (rounding_errors and sigdigs>=0.1)",
  E = NULL,
  parameter_uncertainty_method = NULL,
  ...
)

Value

(IOVSearchResults) IOVSearch tool result object

Arguments

model

(Model) Pharmpy model

results

(ModelfitResults) Results for model

column

(str) Name of column in dataset to use as occasion column (default is 'OCC')

list_of_parameters

(array(str or array(str)) (optional)) List of parameters to test IOV on, if none all parameters with IIV will be tested (default)

rank_type

(str) Which ranking type should be used. Default is BIC.

cutoff

(numeric (optional)) Cutoff for which value of the ranking type that is considered significant. Default is NULL (all models will be ranked)

distribution

(str) Which distribution added IOVs should have (default is same-as-iiv)

strictness

(str (optional)) Strictness criteria

E

(numeric or str (optional)) Expected number of predictors (used for mBIC). Must be set when using mBIC

parameter_uncertainty_method

(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes parameter uncertaint

...

Arguments to pass to tool

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
results <- load_example_modelfit_results("pheno")
run_iovsearch(model=model, results=results, column='OCC')
}

Run the code above in your browser using DataLab