powered by
Run IOVsearch tool. For more details, see :ref:iovsearch.
iovsearch
run_iovsearch( model, results, column = "OCC", list_of_parameters = NULL, rank_type = "bic", cutoff = NULL, distribution = "same-as-iiv", strictness = "minimization_successful or (rounding_errors and sigdigs>=0.1)", E = NULL, parameter_uncertainty_method = NULL, ... )
(IOVSearchResults) IOVSearch tool result object
(Model) Pharmpy model
(ModelfitResults) Results for model
(str) Name of column in dataset to use as occasion column (default is 'OCC')
(array(str or array(str)) (optional)) List of parameters to test IOV on, if none all parameters with IIV will be tested (default)
(str) Which ranking type should be used. Default is BIC.
(numeric (optional)) Cutoff for which value of the ranking type that is considered significant. Default is NULL (all models will be ranked)
(str) Which distribution added IOVs should have (default is same-as-iiv)
(str (optional)) Strictness criteria
(numeric or str (optional)) Expected number of predictors (used for mBIC). Must be set when using mBIC
(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes parameter uncertaint
Arguments to pass to tool
if (FALSE) { model <- load_example_model("pheno") results <- load_example_modelfit_results("pheno") run_iovsearch(model=model, results=results, column='OCC') }
Run the code above in your browser using DataLab