Run ModelRank tool.
run_modelrank(
models,
results,
ref_model,
strictness = "minimization_successful or (rounding_errors and sigdigs >= 0.1)",
rank_type = "ofv",
alpha = 0.05,
search_space = NULL,
E = NULL,
parameter_uncertainty_method = NULL,
exclude_reference_model = FALSE,
...
)(ModelRankResults) ModelRank tool result object
(array(Model)) Models to rank
(array(ModelfitResults)) Modelfit results to rank on
(Model) Model to compare to
(str) Strictness criteria
(str) Which ranking type should be used. Supported types are OFV, LRT, AIC, BIC (mixed, IIV, random), and mBIC (mixed, IIV, random). Default is OFV.
(numeric (optional)) Cutoff p-value that is considered significant in likelihood ratio test. Default is NULL
(str or ModelFeatures (optional)) Search space to test. Either as a string or a ModelFeatures object.
(numeric or str or list(numeric or str,numeric or str) (optional)) Expected number of predictors (used for mBIC). Must be set when using mBIC. Tuple if mBIC for IIV (both diagonals and off-diagonals)
(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes parameter uncertainty
(logical) Should it be possible to select the reference model? Default is TRUE
Arguments to pass to tool