powered by
Run the structsearch tool. For more details, see :ref:structsearch.
structsearch
run_structsearch( model, results, type, search_space = NULL, b_init = NULL, emax_init = NULL, ec50_init = NULL, met_init = NULL, extra_model = NULL, rank_type = "bic", cutoff = NULL, strictness = "minimization_successful or (rounding_errors and sigdigs >= 0.1)", extra_model_results = NULL, dv_types = NULL, parameter_uncertainty_method = NULL, ... )
(StructSearchResult) structsearch tool result object
(Model) Pharmpy start model
(ModelfitResults) Results for the start model
(str) Type of model. Currently only 'drug_metabolite', 'pkpd' and 'tmdd'
(str or ModelFeatures (optional)) Search space to test
(numeric (optional)) Initial estimate for the baseline for pkpd models.
(numeric (optional)) Initial estimate for E_MAX (for pkpd models only).
(numeric (optional)) Initial estimate for EC_50 (for pkpd models only).
(numeric (optional)) Initial estimate for MET (for pkpd models only).
(Model (optional)) Optional extra Pharmpy model to use in TMDD structsearch
(str) Results for the extra model
(numeric (optional)) Which ranking type should be used. Default is BIC.
(str (optional)) Cutoff for which value of the ranking function that is considered significant. Default is NULL (all models will be ranked)
(ModelfitResults (optional)) Strictness criteria
(list(str=numeric) (optional)) Dictionary of DV types for TMDD models with multiple DVs
(str (optional)) Parameter uncertainty method. Will be used in ranking models if strictness includes parameter uncertaint
Arguments to pass to tool
if (FALSE) { model <- load_example_model("pheno") results <- load_example_modelfit_results("pheno") run_structsearch(model=model, results=results, model_type='pkpd') }
Run the code above in your browser using DataLab