Learn R Programming

pharmr (version 2.2.0)

set_n_transit_compartments: set_n_transit_compartments

Description

Set the n-transit compartments model

This is the absorption delay model where the number of transit compartments is a parameter to be estimated (1) (2). Initial estimate for absorption rate is set the previous rate if available, otherwise it is set to the time of first observation/2. Initial estimate for the number of transit compartments is set to 2.

Currently only handles a single oral route of administration. Assumes complete absorption between doses

(1) Savic, R.M., Jonker, D.M., Kerbusch, T. et al. Implementation of a transit compartment model for describing drug absorption in pharmacokinetic studies. J Pharmacokinet Pharmacodyn 34, 711–726 (2007). https://doi.org/10.1007/s10928-007-9066-0

(2) Shen, J., Boeckmann, A. & Vick, A. Implementation of dose superimposition to introduce multiple doses for a mathematical absorption model (transit compartment model). J Pharmacokinet Pharmacodyn 39, 251–262 (2012). https://doi.org/10.1007/s10928-012-9247-3

Usage

set_n_transit_compartments(model, keep_depot = TRUE)

Value

(Model) Updated Pharmpy model

Arguments

model

(Model) Pharmpy model

keep_depot

(logical) FALSE to convert depot compartment into a transit compartment

See Also

add_lag_time

set_transit_compartments

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
model <- set_n_transit_compartments(model)
}

Run the code above in your browser using DataLab