View source: R/functions_wrapper.R
| set_placebo_model | R Documentation |
Add a placebo or disease progression effect to a model.
warning:: This function is under development.
linear
(equation could not be rendered, see API doc on website)
exp_decrease
(equation could not be rendered, see API doc on website)
exp_increase
(equation could not be rendered, see API doc on website)
tmax
(equation could not be rendered, see API doc on website)
(equation could not be rendered, see API doc on website)
set_placebo_model(model, expr, operator = "*")
model |
(Model) Pharmpy model |
expr |
(str) Name of placebo/disease progression effect function. |
operator |
(str) Operator to use for combining the baseline with the placebo/disease progression |
(Model) Updated Pharmpy model
## Not run:
model <- create_basic_pd_model()
model <- set_placebo_model(model, "linear")
model$statements$find_assignment("PDP")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.