Learn R Programming

pharmr (version 2.2.0)

set_transit_compartments: set_transit_compartments

Description

Set the number of transit compartments of model.

Initial estimate for the absorption delay is set the previous delay if available, otherwise it is set to the time of first observation/2.

Usage

set_transit_compartments(model, n, keep_depot = TRUE)

Value

(Model) Updated Pharmpy model

Arguments

model

(Model) Pharmpy model

n

(numeric) Number of transit compartments

keep_depot

(logical) FALSE to convert depot compartment into a transit compartment

See Also

add_lag_time

set_n_transit_compartments

Examples

Run this code
if (FALSE) {
model <- load_example_model("pheno")
model <- set_transit_compartments(model, 3)
model$statements$ode_system
}

Run the code above in your browser using DataLab