powered by
Set the number of transit compartments of model.
Initial estimate for the absorption delay is set the previous delay if available, otherwise it is set to the time of first observation/2.
set_transit_compartments(model, n, keep_depot = TRUE)
(Model) Updated Pharmpy model
(Model) Pharmpy model
(numeric) Number of transit compartments
(logical) FALSE to convert depot compartment into a transit compartment
add_lag_time
set_n_transit_compartments
if (FALSE) { model <- load_example_model("pheno") model <- set_transit_compartments(model, 3) model$statements$ode_system }
Run the code above in your browser using DataLab