View source: R/functions_wrapper.R
| write_model | R Documentation |
Write model code to file
An updated Pharmpy model is returned. This will have a new name based on the filename and it might have updates to the model code (e.g. for $DATA in NONMEM models).
write_model(model, path = "", force = TRUE)
model |
(Model) Pharmpy model |
path |
(str) Destination path |
force |
(logical) Force overwrite, default is TRUE |
(Model) Updated Pharmpy model
## Not run:
model <- load_example_model("pheno")
write_model(model)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.