powered by
Write model code to file
An updated Pharmpy model is returned. This will have a new name based on the filename and it might have updates to the model code (e.g. for $DATA in NONMEM models).
write_model(model, path = "", force = TRUE)
(Model) Updated Pharmpy model
(Model) Pharmpy model
(str) Destination path
(logical) Force overwrite, default is TRUE
if (FALSE) { model <- load_example_model("pheno") write_model(model) }
Run the code above in your browser using DataLab